.. Merchant Documentation documentation master file, created by
   sphinx-quickstart on Mon Oct 18 21:09:11 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Merchant's documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

* :doc:`Overview <overview>`
* :doc:`Install Merchant <install>`
* :doc:`Credit Card <credit_card>`
* :doc:`Gateways <gateways>`

  * :doc:`On-site Processing <onsite_processing>`

    * :doc:`Authorize.Net <gateways/authorize_net>`
    * :doc:`Braintree Payments Server to Server <gateways/braintree_payments>`
    * :doc:`eWay <gateways/eway_gateway>`
    * :doc:`PayPal <gateways/paypal_gateway>`
    * :doc:`Samurai Payment <gateways/samurai_gateway>`
    * :doc:`Stripe Payments  <gateways/stripe_payment>`

  * :doc:`Off-site Processing <offsite_processing>`

    * :doc:`PayPal <offsite/paypal>`
    * :doc:`Google Checkout <offsite/google_checkout>`
    * :doc:`RBS WorldPay <offsite/rbs_worldpay>`
    * :doc:`Amazon FPS <offsite/amazon_fps>`
    * :doc:`Braintree Payments Transparent Redirect <offsite/braintree_payments>`
    * :doc:`Stripe  <offsite/stripe_integration>`
    * :doc:`Samurai  <offsite/samurai_integration>`

* :doc:`Signals <signals>`
* :doc:`Writing your own gateway <custom_gateway>`
* :doc:`Customizing the inbuilt Gateway/Integrations <customize>`
* :doc:`Contributing to Merchant <contributing>`
* :doc:`Changelist <changelist>`

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
